==> tasks-2.1-sources.jar: hudson/plugins/tasks/Messages.java <==

package hudson.plugins.tasks;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * Package
     * 
     */
    public static String Tasks_ResultAction_Category_Package() {
        return holder.format("Tasks.ResultAction.Category.Package");
    }

    /**
     * Package
     * 
     */
    public static Localizable _Tasks_ResultAction_Category_Package() {
        return new Localizable(holder, "Tasks.ResultAction.Category.Package");
    }

    /**
     * Task Scanner:
     * 
     */
    public static String Tasks_ResultAction_Summary() {
        return holder.format("Tasks.ResultAction.Summary");
    }

    /**
     * Task Scanner:
     * 
     */
    public static Localizable _Tasks_ResultAction_Summary() {
        return new Localizable(holder, "Tasks.ResultAction.Summary");
    }

    /**
     * {0} open tasks
     * 
     */
    public static String Tasks_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Tasks.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} open tasks
     * 
     */
    public static Localizable _Tasks_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Tasks.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * Namespace
     * 
     */
    public static String Tasks_ResultAction_Category_Namespace() {
        return holder.format("Tasks.ResultAction.Category.Namespace");
    }

    /**
     * Namespace
     * 
     */
    public static Localizable _Tasks_ResultAction_Category_Namespace() {
        return new Localizable(holder, "Tasks.ResultAction.Category.Namespace");
    }

    /**
     * Priority {0}
     * 
     */
    public static String Tasks_Source_PriorityTooltip(Object arg1) {
        return holder.format("Tasks.Source.PriorityTooltip", arg1);
    }

    /**
     * Priority {0}
     * 
     */
    public static Localizable _Tasks_Source_PriorityTooltip(Object arg1) {
        return new Localizable(holder, "Tasks.Source.PriorityTooltip", arg1);
    }

    /**
     * in {0} workspace files
     * 
     */
    public static String Tasks_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Tasks.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} workspace files
     * 
     */
    public static Localizable _Tasks_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Tasks.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Scan workspace for open tasks
     * 
     */
    public static String Tasks_Publisher_Name() {
        return holder.format("Tasks.Publisher.Name");
    }

    /**
     * Scan workspace for open tasks
     * 
     */
    public static Localizable _Tasks_Publisher_Name() {
        return new Localizable(holder, "Tasks.Publisher.Name");
    }

    /**
     * in 1 workspace file
     * 
     */
    public static String Tasks_ResultAction_OneFile() {
        return holder.format("Tasks.ResultAction.OneFile");
    }

    /**
     * in 1 workspace file
     * 
     */
    public static Localizable _Tasks_ResultAction_OneFile() {
        return new Localizable(holder, "Tasks.ResultAction.OneFile");
    }

    /**
     * Open Tasks
     * 
     */
    public static String Tasks_ProjectAction_Name() {
        return holder.format("Tasks.ProjectAction.Name");
    }

    /**
     * Open Tasks
     * 
     */
    public static Localizable _Tasks_ProjectAction_Name() {
        return new Localizable(holder, "Tasks.ProjectAction.Name");
    }

    /**
     *  1 open task
     * 
     */
    public static String Tasks_ResultAction_OneWarning() {
        return holder.format("Tasks.ResultAction.OneWarning");
    }

    /**
     *  1 open task
     * 
     */
    public static Localizable _Tasks_ResultAction_OneWarning() {
        return new Localizable(holder, "Tasks.ResultAction.OneWarning");
    }

}

==> tasks-2.4-sources.jar: hudson/plugins/tasks/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.tasks;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = new ResourceBundleHolder(Messages.class);

    /**
     * Task Scanner: {0} open tasks found.
     * 
     */
    public static String Tasks_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Tasks.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Task Scanner: {0} open tasks found.
     * 
     */
    public static Localizable _Tasks_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Tasks.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Task Scanner:
     * 
     */
    public static String Tasks_ResultAction_Summary() {
        return holder.format("Tasks.ResultAction.Summary");
    }

    /**
     * Task Scanner:
     * 
     */
    public static Localizable _Tasks_ResultAction_Summary() {
        return new Localizable(holder, "Tasks.ResultAction.Summary");
    }

    /**
     * {0} open tasks
     * 
     */
    public static String Tasks_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Tasks.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} open tasks
     * 
     */
    public static Localizable _Tasks_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Tasks.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * in {0} workspace files
     * 
     */
    public static String Tasks_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("Tasks.ResultAction.MultipleFiles", arg1);
    }

    /**
     * in {0} workspace files
     * 
     */
    public static Localizable _Tasks_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "Tasks.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Task Scanner: 1 open task found.
     * 
     */
    public static String Tasks_ResultAction_HealthReportSingleItem() {
        return holder.format("Tasks.ResultAction.HealthReportSingleItem");
    }

    /**
     * Task Scanner: 1 open task found.
     * 
     */
    public static Localizable _Tasks_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Tasks.ResultAction.HealthReportSingleItem");
    }

    /**
     * Scan workspace for open tasks
     * 
     */
    public static String Tasks_Publisher_Name() {
        return holder.format("Tasks.Publisher.Name");
    }

    /**
     * Scan workspace for open tasks
     * 
     */
    public static Localizable _Tasks_Publisher_Name() {
        return new Localizable(holder, "Tasks.Publisher.Name");
    }

    /**
     * in 1 workspace file
     * 
     */
    public static String Tasks_ResultAction_OneFile() {
        return holder.format("Tasks.ResultAction.OneFile");
    }

    /**
     * in 1 workspace file
     * 
     */
    public static Localizable _Tasks_ResultAction_OneFile() {
        return new Localizable(holder, "Tasks.ResultAction.OneFile");
    }

    /**
     * Open Tasks
     * 
     */
    public static String Tasks_ProjectAction_Name() {
        return holder.format("Tasks.ProjectAction.Name");
    }

    /**
     * Open Tasks
     * 
     */
    public static Localizable _Tasks_ProjectAction_Name() {
        return new Localizable(holder, "Tasks.ProjectAction.Name");
    }

    /**
     *  1 open task
     * 
     */
    public static String Tasks_ResultAction_OneWarning() {
        return holder.format("Tasks.ResultAction.OneWarning");
    }

    /**
     *  1 open task
     * 
     */
    public static Localizable _Tasks_ResultAction_OneWarning() {
        return new Localizable(holder, "Tasks.ResultAction.OneWarning");
    }

}
